ArbPartDto class
Constructors
Properties
-
args
→ Map<
String, String> -
no setter
- description → String?
-
final
- extra → Json
-
no setter
- hasExtra → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isMethod → bool
-
no setter
- name → String
-
final
-
placeholders
→ List<
IPlaceholder> -
no setter
-
placeholdersRaw
→ Map<
String, dynamic> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
translates
→ Map<
String, String> ? -
final
- value → String
-
final
Methods
-
locales(
String mainLocale) → List< String> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Json -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Json data) → ArbPartDto